from bs4 import BeautifulSoup
import sys
import requests
import json

def main():
    if len(sys.argv) > 2:
        if sys.argv[1] == "search":
            results = google_searcher(sys.argv[2])
            results = json.dumps(results)
            print(results)

def google_searcher(item):
    search_response = requests.get("https://www.google.com/search?q=" + item)
    
    if search_response.status_code == 200:
        soup = BeautifulSoup(search_response.text, 'lxml') 
        search_content = soup.get_text()
        return search_content
    else:
        print("Error: Unable to fetch search results.")
        return None

if __name__ == "__main__":
    main()



from setuptools import setup


setup(
    name='search-terminal',
    version='0.0.1',
    author="Babalo Majiyezi",
    author_email="raymondbabalo5@gmail.com",
    description="This is a program that allows you to search the web from the comfort of your terminal.",
    long_description="file: README.md",
    long_description_content_type="text/markdown",
    packages=["search_package"], 
    url="https://github.com/Dr-GameDev/Google-Search_Package",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    install_requires=[
        'beautifulsoup4',
        'requests',
    ],
    entry_points={
        'console_scripts': [
            'go-search = search_package.search:main', 
        ],
    },
)
